  CREATE OR REPLACE VIEW ACCESS_REVIEW_DETAILS_V AS 
   SELECT DISTINCT
    item.id review_item_id,
    item.last_override_action_id last_override_action,
    instance.id review_instance_id,
    instance.status review_status,
    instance.start_date,
    instance.end_date,
    instance.valid_to_date,
    instance.item_count,
    multi_owner.review_owners,
    multi_reviewer.reviewer_ids reviewer_id,
        CASE
            WHEN item.final_cert_by_unique_user_id IS NOT NULL THEN TO_CHAR(final_reviewer.display_name)
            ELSE TO_CHAR(multi_reviewer.reviewers)
        END reviewer_display_name,
    reassigned_by_history.reviewers reassigned_by_user_disp_name,
    reassigned_from_history.reviewers reassigned_from_user_disp_name,
    reassigned_by_history.reassigned_date,
    defn.name review_name,
    TO_CHAR(substr(defn.description,0,4000)) description,
    defn.review_type,
    defn.next_schedule_date,
    CASE
        WHEN item_type = 'ACCOUNT' AND usr.id IS NULL THEN shacc.suser  
        ELSE usr.id
    END user_id,
    CASE
        WHEN item_type = 'ACCOUNT' AND usr.display_name IS NULL THEN TO_CHAR(shacc.display_name)
        ELSE TO_CHAR(usr.display_name)
    END user_display_name,
    action.action reviewer_action,
    action.review_order,
    action.reviewer_comment,
    perm.id permission_id,
    perm.name permission_name,
    acct.id account_id,
    acct.account_id account_native_id,
    acct.name account_name,
    acct.relation_to_user_type account_relation,
    TO_CHAR(app.id) application_id,
    TO_CHAR(app_ds.name) application_name,
    item.final_decision,
    item.final_decision_time,
    role.id role_id,
    role.name role_name,
    item.item_type,
    brole.name brole_name,
    action.fulfillment_instructions,
    esc_reviewer.display_name
   FROM review_item item
     JOIN review_instance instance ON item.review_instance_id = instance.id
     JOIN review_definition defn ON instance.review_definition = defn.id 
     LEFT JOIN suser usr ON usr.unique_user_id = item.unique_user_id AND usr.effective = 1
     LEFT JOIN spermission perm ON perm.unique_permission_id = item.unique_permission_id AND perm.effective = 1
     LEFT JOIN saccount acct ON acct.unique_account_id = item.unique_account_id AND acct.effective = 1
     LEFT JOIN application app ON app.id =
        CASE
            WHEN perm.id IS NULL THEN acct.application
            ELSE perm.application
        END
     LEFT JOIN business_role brole ON brole.id = item.business_role_id
     LEFT JOIN role_policy role ON role.id = item.role_id
     LEFT JOIN data_source app_ds ON app_ds.id = app.id
     LEFT JOIN review_item_action action ON action.review_item_id = item.id AND action.action <> 'REASSIGNED'
     LEFT JOIN reviewer_instance inst2 ON instance.id = inst2.review_instance_id AND inst2.type = 'RO'
     LEFT JOIN reviewer_instance inst3 ON instance.id = inst3.review_instance_id
     LEFT JOIN ( SELECT DISTINCT 
              item.id item_id,
              LISTAGG((TO_CHAR(multi_reviewers.id)), ' | ') WITHIN GROUP(ORDER BY multi_reviewers.id) reviewer_ids,
              LISTAGG((TO_CHAR(multi_reviewers.unique_user_id)), ' | ') WITHIN GROUP(ORDER BY multi_reviewers.unique_user_id) reviewer_unique_ids,
              LISTAGG((TO_CHAR(multi_reviewers.display_name)), ' | ') WITHIN GROUP(ORDER BY multi_reviewers.display_name) reviewers
            FROM review_item item
            LEFT JOIN reviewer_user_instance rrui ON rrui.reviewer_instance_id = item.curr_reviewer_instance_id
            LEFT JOIN suser multi_reviewers ON rrui.unique_user_id = multi_reviewers.unique_user_id AND multi_reviewers.effective = 1
            GROUP BY item.id) multi_reviewer ON multi_reviewer.item_id = item.id
     LEFT JOIN suser final_reviewer ON item.final_cert_by_unique_user_id = final_reviewer.unique_user_id AND final_reviewer.effective = 1
     LEFT JOIN suser acting_reviewer ON action.acted_by_user_unique_id = acting_reviewer.unique_user_id AND acting_reviewer.effective = 1
     LEFT JOIN review_item_action reassigned ON reassigned.review_item_id = item.id AND reassigned.action = 'REASSIGNED' AND reassigned.reassigned_to_user_unique_id LIKE '%' || multi_reviewer.reviewer_unique_ids || '%'
     LEFT JOIN suser curr_reviewer ON curr_reviewer.unique_user_id LIKE '%' || multi_reviewer.reviewer_unique_ids || '%' AND curr_reviewer.effective = 1
     LEFT JOIN (SELECT DISTINCT 
      ria.review_item_id,
      LISTAGG(TO_CHAR(usr.display_name), ' | ') WITHIN GROUP(ORDER BY ria.assigned) AS reviewers
      FROM  review_item_action ria
      LEFT JOIN reviewer_instance ri ON ri.id = ria.reviewer_instance_id
      LEFT JOIN suser usr ON ri.single_reviewer_unique_id = usr.unique_user_id AND usr.effective = 1
      WHERE ria.action = 'REASSIGNED'
      GROUP BY ria.review_item_id) reassigned_from_history ON reassigned_from_history.review_item_id = item.id
     LEFT JOIN (SELECT DISTINCT 
      ria.review_item_id,
      LISTAGG(TO_CHAR(usr.display_name), ' | ') WITHIN GROUP(ORDER BY ria.assigned) AS reviewers,
      LISTAGG(TO_CHAR(CAST(ria.assigned AS DATE), 'YYYY-MM-DD HH24:MI:SS'), ' | ') WITHIN GROUP(ORDER BY ria.assigned) AS reassigned_date
      FROM  review_item_action ria
      LEFT JOIN suser usr ON ria.reassigned_by_user_unique_id = usr.unique_user_id AND usr.effective = 1
      WHERE ria.action = 'REASSIGNED'
      GROUP BY ria.review_item_id) reassigned_by_history ON reassigned_by_history.review_item_id = item.id
     LEFT JOIN shared_accounts_v shacc ON shacc.unique_account_id = acct.unique_account_id
     LEFT JOIN ( SELECT DISTINCT defn_1.name review_name,
            ri.id rid,
            LISTAGG((TO_CHAR(s.display_name)), ' | ') WITHIN GROUP(ORDER BY s.display_name) review_owners
           FROM review_instance ri
             JOIN review_definition defn_1 ON ri.review_definition = defn_1.id
             LEFT JOIN reviewer_instance rev_owner ON ri.id = rev_owner.review_instance_id AND rev_owner.type = 'RO'
             LEFT JOIN reviewer_user_instance rui ON rui.reviewer_instance_id = rev_owner.id
             LEFT JOIN suser s ON rui.unique_user_id = s.unique_user_id AND s.effective = 1
          GROUP BY defn_1.name, ri.id) multi_owner ON multi_owner.rid = item.review_instance_id   
     LEFT JOIN (SELECT 
      esc_reviewers.review_instance_id,
      LISTAGG(TO_CHAR(esc_reviewers.display_name), ' | ') WITHIN GROUP (ORDER BY esc_reviewers.display_name) display_name
      FROM
        (SELECT DISTINCT
              TO_CHAR(u.display_name) display_name,
              rri.review_instance_id
        FROM review_item ri
        JOIN reviewer_instance rri ON ri.curr_reviewer_instance_id = rri.id AND rri.type = 'EO'
        JOIN reviewer_user_instance rriu ON rriu.reviewer_instance_id = rri.id
        JOIN suser u ON u.unique_user_id = rriu.unique_user_id AND u.effective = 1) esc_reviewers
      GROUP BY esc_reviewers.review_instance_id) esc_reviewer ON esc_reviewer.review_instance_id = item.review_instance_id
  WHERE defn.deleted = 0 AND (acting_reviewer.unique_user_id LIKE '%' || multi_reviewer.reviewer_unique_ids || '%' OR acting_reviewer.unique_user_id IS NULL AND action.review_order = (( SELECT DISTINCT min(act.review_order) min
           FROM review_item_action act
          WHERE (act.action = 'PENDING' OR act.action = 'ESCALATE') AND act.review_item_id = item.id)) OR acting_reviewer.unique_user_id IS NOT NULL AND action.shared_queue = 1) AND (action.action <> 'PENDING' OR item.final_decision IS NULL)
  ORDER BY item.id, action.review_order;


GRANT SELECT ON igops.access_review_details_v TO igrptuser;
CREATE OR REPLACE PUBLIC SYNONYM access_review_details_v for igops.access_review_details_v;